@@ -9,11 +9,12 @@ import sys
 import threading
 import time
 
-import xonsh.lazyasd as xl
-import xonsh.lazyimps as xli
+import xonsh.lib.lazyasd as xl
+import xonsh.lib.lazyimps as xli
 import xonsh.platform as xp
 import xonsh.tools as xt
 from xonsh.built_ins import XSH
+from xonsh.procs.jobs import proc_untraced_waitpid
 from xonsh.procs.readers import (
     BufferedFDParallelReader,
     NonBlockingFDReader,
@@ -103,6 +104,14 @@ class PopenThread(threading.Thread):
             raise
 
         self.pid = proc.pid
+        self.name = repr(
+            {
+                "cls": self.__class__.__name__,
+                "name": self.name,
+                "cmd": args,
+                "pid": self.pid,
+            }
+        )
         self.universal_newlines = uninew = proc.universal_newlines
         if uninew:
             self.encoding = enc = env.get("XONSH_ENCODING")
@@ -160,6 +169,16 @@ class PopenThread(threading.Thread):
         # loop over reads while process is running.
         i = j = cnt = 1
         while proc.poll() is None:
+            info = proc_untraced_waitpid(proc, hang=False)
+            if getattr(proc, "suspended", False):
+                self.suspended = True
+                if XSH.env.get("XONSH_DEBUG", False):
+                    procname = f"{getattr(proc, 'args', '')} {proc.pid}".strip()
+                    print(
+                        f"Process {procname} suspended with signal {info['signal_name']}.",
+                        file=sys.stderr,
+                    )
+
             # this is here for CPU performance reasons.
             if i + j == 0:
                 cnt = min(cnt + 1, 1000)
@@ -290,7 +309,7 @@ class PopenThread(threading.Thread):
             return
         # Get the terminal size of the real terminal, set it on the
         #       pseudoterminal.
-        buf = array.array("h", [0, 0, 0, 0])
+        buf = array.array("h", [0, 0, 0, 0, 0, 0, 0, 0])
         # 1 = stdout here
         try:
             xli.fcntl.ioctl(1, xli.termios.TIOCGWINSZ, buf, True)
